==> painted-5.x-1.0.tar.gz: painted/node.tpl.php <==
	<?php // $Id: node.tpl.php,v 1.1.2.4 2008/10/22 23:33:55 couzinhub Exp $ ?>

	<?php if ($teaser): ?>

		<div <?php if ($node->nid) { echo 'id="node-' . $node->nid .'"' ; } ?> class="teaser node<?php if ($sticky) { echo " sticky"; } ?><?php if (!$status) { echo " node-unpublished"; } ?> <?php if (!$node->nid) { echo "no-nid" ; } ?>">

			<?php if ($submitted): ?>
				<div class="submitted"><?php echo t( format_date($node->created, 'custom', "F jS, Y")); ?></div>
			<?php endif; ?>
			
					<?php if ($page == 0): ?>
						<h2 class="title node-title"> <a href="<?php echo $node_url ?>"><?php echo $title ?></a> </h2>
					<?php endif; ?>
					
		  		<div class="content">
		  		  <?php echo $content?>
		  		</div>

		  		<?php if ($links): ?> <div class="links"> <?php echo $links ?> </div> <?php endif; ?>

		</div>


	<?php else : ?>

<div <?php if ($node->nid) { echo 'id="node-' . $node->nid .'"' ; } ?> class="full node <?php if (!$status) { echo " node-unpublished"; } ?> <?php if (!$node->nid) { echo "no-nid" ; } ?>">
  
			<?php if ($page == 0): ?>
				<h2 class="title node-title"> <a href="<?php echo $node_url ?>"><?php echo $title ?></a> </h2>
			<?php endif; ?>
  		
  		<div class="content">
  		  <?php echo $content?>
  		</div>
  		
			<?php if ($node->nid): ?>
				<div class="meta">
	  			<?php if ($picture) echo $picture ?>
      	
					<?php if ($submitted or $has_terms): ?>
							<div class="submitted"><?php echo t('Posted on !date by !name at !hour', array('!date' => format_date($node->created, 'custom', "F jS, Y"), '!name' => theme('username', $node), '!hour' => format_date($node->created, 'custom', "g:ia"))); ?>
								<?php if ($has_terms): ?>
									<div class="taxonomy"><strong><?php echo t('Tagged in: ') ;?></strong><?php echo $terms ?></div>
								<?php endif; ?>
							</div>
	  			<?php endif; ?>
	   			<div class="clear-block"></div>
	    	
				</div>
			<?php endif; ?>

  		<?php if ($links): ?> <div class="links"> <?php echo $links ?> </div> <?php endif; ?>

</div>

<?php endif; ?>

==> painted-5.x-1.1.tar.gz: painted/node.tpl.php <==
	<?php // $Id: node.tpl.php,v 1.1.2.6 2008/11/29 07:40:40 couzinhub Exp $ ?>

	<?php if ($teaser): ?>

		<div <?php if ($node->nid) { echo 'id="node-' . $node->nid .'"' ; } ?> class="teaser node<?php if ($sticky) { echo " sticky"; } ?><?php if (!$status) { echo " node-unpublished"; } ?> <?php if (!$node->nid) { echo "no-nid" ; } ?>">

			<?php if ($submitted): ?>
				<div class="submitted"><?php echo t( format_date($node->created, 'medium')); ?></div>
			<?php endif; ?>
			
					<?php if ($page == 0): ?>
						<h2 class="title node-title"> <a href="<?php echo $node_url ?>"><?php echo $title ?></a> </h2>
					<?php endif; ?>
					
		  		<div class="content">
		  		  <?php echo $content?>
		  		</div>

		  		<?php if ($links): ?> <div class="links clearboth"> <?php echo $links ?> </div> <?php endif; ?>

		</div>


	<?php else : ?>

		<div <?php if ($node->nid) { echo 'id="node-' . $node->nid .'"' ; } ?> class="full node <?php if (!$status) { echo " node-unpublished"; } ?> <?php if (!$node->nid) { echo "no-nid" ; } ?>">
  
			<?php if ($page == 0): ?>
				<h2 class="title node-title"> <a href="<?php echo $node_url ?>"><?php echo $title ?></a> </h2>
			<?php endif; ?>
  		
  		<div class="content">
  		  <?php echo $content?>
 				<div class="clear-block"></div>
			</div>
  		
			<?php if ($node->nid): ?>
				<div class="meta">
	  			<?php if ($picture) echo $picture ?>
      	
					<?php if ($submitted or $has_terms): ?>
							<div class="submitted"><?php echo t('Posted on !date by !name', array('!date' => format_date($node->created, 'medium'), '!name' => theme('username', $node))); ?>
								<?php if ($has_terms): ?>
									<div class="taxonomy"><strong><?php echo t('Tagged in: ') ;?></strong><?php echo $terms ?></div>
								<?php endif; ?>
							</div>
	  			<?php endif; ?>

 			<div class="clear-block"></div>
	    	
				</div>
			<?php endif; ?>

  		<?php if ($links): ?> <div class="links"> <?php echo $links ?> </div> <?php endif; ?>

</div>

<?php endif; ?>
